package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.28.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.28.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@("`0`````````````#`!8````!````````(D@`````````0```````
M`*$X``````!``#@`"`!``!8`%0````8````$`````````$``````````0```
M``````!``````````<`````````!P``````````(`````P````0````````"
M``````````(``````````@``````````&``````````8``````````$````!
M````!0```````````````````````````````````````)JH````````FJ@`
M```````0``````$````&````````F]@```````"KV````````*O8````````
M!*`````````5"````````!```````@````8```````";^````````*OX````
M````J_@````````!H`````````&@``````````AD=.50````!````````)3@
M````````E.````````"4X`````````#4`````````-0`````````!&1TY5$`
M```&````````````````````````````````````````````````````````
M```````09'3E4@````0```````";V````````*O8````````J]@````````$
M*`````````0H``````````$O;&EB+VQD+6UU<VPM<S,Y,'@N<V\N,0`````1
M````20````0````(@`1`!0`0$""$`(:`!!``*`D$``D``"&""`($ND$8@(@`
M````````20```$T```!1````4@```%@```!9````6@````````!<````70``
M``````!>````7P```&$``````````'R:?VH.[]/J+4?>SA_?Q6^VF\4N#O&-
MN'S49-0.Y/\A'%AQV6!LH?HL/^7";XL!LH?7^D(!QD?B?)+CN](\PU5FS*]G
MTW`'B.S514/MVV(SS"6,%9N<J7\*`J?@4)X::TG[X*,`````````````````
M`````````````````````P``!P```````!AP```````````````,$@``````
M``````````````````````&S$@`````````````````````````````4$0``
M``````````````````````````'9$0````````````````````````````%5
M$@`````````````````````````````;$@``````````````````````````
M``&2$@`````````````````````````````C$@``````````````````````
M```````J$@````````````````````````````'F$@``````````````````
M``````````&>$@`````````````````````````````S(```````````````
M``````````````,8(0````````````````````````````!+$@``````````
M``````````````````!1$@````````````````````````````+E$@``````
M``````````````````````+6$@````````````````````````````)K$@``
M``````````````````````````(,$@````````````````````````````!8
M$@````````````````````````````*@$@``````````````````````````
M``!?$@````````````````````````````!G$@``````````````````````
M``````*)$@````````````````````````````!O$@``````````````````
M``````````!U$@````````````````````````````!^(```````````````
M``````````````+/$@````````````````````````````":$@``````````
M``````````````````"?$@````````````````````````````'W$0``````
M``````````````````````*G$@````````````````````````````(Y$@``
M``````````````````````````"F$@````````````````````````````(K
M$@````````````````````````````,\$@``````````````````````````
M``,7$0````````````````````````````)=$@``````````````````````
M``````,$$@````````````````````````````,9$0``````````````````
M``````````"M$@````````````````````````````+\$@``````````````
M``````````````%C$@````````````````````````````"V(@``````````
M``````````````````#%(`````````````````````````````#;$@``````
M``````````````````````+'$@````````````````````````````))$@``
M``````````````````````````#@$@````````````````````````````#F
M(`````````````````````````````*4$@``````````````````````````
M``$`$@````````````````````````````&#$@``````````````````````
M``````$%$@````````````````````````````)Y$@``````````````````
M``````````%R$@````````````````````````````$+$@``````````````
M``````````````$<$@````````````````````````````('$@``````````
M``````````````````!P$@````````````````````````````(8$@``````
M``````````````````````)2$@````````````````````````````+U$@``
M``````````````````````````$B$@````````````````````````````+M
M$@````````````````````````````$V$@``````````````````````````
M``("$@````````````````````````````'!$@``````````````````````
M``````$]$@````````````````````````````,6(0``````````````````
M``````````%.$@````````````````````````````,1$@``"0```````"`8
M`````````BH```'3$@``"@```````%<X``````````(```-^$@``"0``````
M`#(8````````!E8```0J$@``"0```````#PP`````````&P```-;$@``"0``
M`````"OP``````````8```/H$@``!P```````!AP``````````(```.A$@``
M"0```````#AP`````````\````0.$@``"0```````"OX`````````>H```/9
M$```$P```````+!X``````````````-L$@``"0```````#%H`````````*P`
M``.+$@``"0```````"HX`````````#P```.3$@``"0```````##(````````
M`'````.W$@``"0```````%1H`````````6````/,$@``"0```````"WH````
M`````"(```0E$```$P```````,#@``````````````,A$@``"0```````")X
M`````````#0```/N$@``"0```````"X0`````````2P```/"$0``$@``````
M`+!P``````````@```0'$```$@```````+!X``````````````/>$@``"0``
M`````")(``````````````/E$@``"0```````%/X`````````&P```,J$@``
M"0```````#$X`````````"X```-%$@``"0```````"K8`````````18```0;
M$@``"0```````%7(`````````1H```/Z$@``"0```````"]``````````8@`
M;&EB<&5R;"YS;P!O<&5N9&ER`'-T9&5R<@!R96%L;&]C`&%C8V5S<P!S;G!R
M:6YT9@!?7V1E<F5G:7-T97)?9G)A;65?:6YF;P!L<V5E:P!G971P:60`=6YL
M:6YK`&UE;6UO=F4`<W1R;F-M<`!L<W1A=`!C;&]S961I<@!?251-7V1E<F5G
M:7-T97)434-L;VYE5&%B;&4`;W!E;@!S=')S='(`<W1R8VAR`')E861L:6YK
M`%]?8WAA7V9I;F%L:7IE`%]?<F5G:7-T97)?9G)A;65?:6YF;P!E>&ET`&-L
M;W-E`%])5$U?<F5G:7-T97)434-L;VYE5&%B;&4`<F5A9`!R;61I<@!?7V5R
M<FYO7VQO8V%T:6]N`&UK9&ER`'!T:')E861?9V5T<W!E8VEF:6,`;65M8W!Y
M`%]?<W1A8VM?8VAK7V9A:6P`9V5T=6ED`%!E<FQ?<WES7W1E<FT`4&5R;%]S
M>7-?:6YI=#,`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!097)L
M7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7V%V7W-H:69T`%!E
M<FQ?<W9?,G!V7V9L86=S`%]F:6YI`%!,7V1O7W5N9'5M<`!097)L7VYE=UA3
M7V9L86=S`%!,7W1H<E]K97D`<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?
M871F;W)K7W5N;&]C:P!097)L7W-V7W-E='!V`%!E<FQ?9W9?9F5T8VAP=@!P
M97)L7W)U;@!097)L7VYE=UA3`'!E<FQ?9&5S=')U8W0`4&5R;%]A=E]F971C
M:`!B;V]T7T1Y;F%,;V%D97(`<&5R;%]P87)S90!097)L7W-A9F5S>7-M86QL
M;V,`<&5R;%]A;&QO8P!L:6)C+FUU<VPM<S,Y,'@N<V\N,0!F<')I;G1F`'-T
M<F1U<`!P=&AR96%D7V%T9F]R:P!R96%D9&ER`'-P<FEN=&8`<W1R=&]K`'-T
M<FYC<'D`7U]L:6)C7W-T87)T7VUA:6X`7U]?96YV:7)O;@!?<W1A<G1?8P!G
M971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?8W5R<F5N=%]E>&5C7W!R
M;V,`<&%R7V-U<G)E;G1?97AE8P!P87)?<V5T=7!?;&EB<&%T:`!P87)?;6MT
M;7!D:7(`>'-?:6YI=`!P87)?96YV7V-L96%N`%A37TEN=&5R;F%L<U]005)?
M0D]/5`!S:&%?=7!D871E`&UY7W!A<E]P;`!P87)?8F%S96YA;64`7U]B<W-?
M<W1A<G0`<VAA7VEN:70`<&%R7V1I<FYA;64`<&%R7VEN:71?96YV`%]E9&%T
M80!P87)?9FEN9'!R;V<`<VAA7V9I;F%L`%]E;F0`<&%R7V-L96%N=7``+W5S
M<B]L:6(O<&5R;#4O8V]R95]P97)L+T-/4D4``````````````*^(````````
M``P````````@&````````*^@``````````P```````!7.````````*^X````
M``````P````````8<````````+````````````P```````"P`````````+`(
M``````````P```````!9B````````+`0``````````P```````!78```````
M`+`@``````````P```````!83````````+`H``````````P```````!84```
M`````+`P``````````P```````!9C@```````+`X``````````P```````!7
ML@```````+!```````````P```````!9E@```````+!0``````````P`````
M``!9F@```````+!8``````````P```````!9H````````+!P``````````P`
M``````!:0@```````*^0````!`````H``````````````````*^8````!0``
M``H``````````````````*^H````#0````H``````````````````*^P````
M'`````H``````````````````*_`````(`````H``````````````````*_(
M````*0````H``````````````````*_0````+0````H`````````````````
M`*_8````+@````H``````````````````*_@````,P````H`````````````
M`````*_H````.`````H``````````````````*_P````.0````H`````````
M`````````*_X````/@````H``````````````````*VP`````@````L`````
M`````````````*VX`````P````L``````````````````*W`````!@````L`
M`````````````````*W(````!P````L``````````````````*W0````"```
M``L``````````````````*W8````"0````L``````````````````*W@````
M"@````L``````````````````*WH````"P````L``````````````````*WP
M````#`````L``````````````````*WX````#0````L`````````````````
M`*X`````#P````L``````````````````*X(````$`````L`````````````
M`````*X0````$0````L``````````````````*X8````$@````L`````````
M`````````*X@````$P````L``````````````````*XH````%`````L`````
M`````````````*XP````%0````L``````````````````*XX````%@````L`
M`````````````````*Y`````%P````L``````````````````*Y(````&```
M``L``````````````````*Y0````&0````L``````````````````*Y8````
M&@````L``````````````````*Y@````&P````L``````````````````*YH
M````'0````L``````````````````*YP````'@````L`````````````````
M`*YX````'P````L``````````````````*Z`````(0````L`````````````
M`````*Z(````(@````L``````````````````*Z0````(P````L`````````
M`````````*Z8````)`````L``````````````````*Z@````)0````L`````
M`````````````*ZH````)P````L``````````````````*ZP````*`````L`
M`````````````````*ZX````*@````L``````````````````*[`````*P``
M``L``````````````````*[(````+`````L``````````````````*[0````
M+0````L``````````````````*[8````+@````L``````````````````*[@
M````+P````L``````````````````*[H````,`````L`````````````````
M`*[P````,0````L``````````````````*[X````,@````L`````````````
M`````*\`````-`````L``````````````````*\(````-0````L`````````
M`````````*\0````-@````L``````````````````*\8````-P````L`````
M`````````````*\@````.@````L``````````````````*\H````.P````L`
M`````````````````*\P````/`````L``````````````````*\X````/0``
M``L``````````````````*]`````/P````L``````````````````*](````
M0`````L``````````````````*]0````00````L``````````````````*]8
M````0@````L``````````````````*]@````0P````L`````````````````
M`*]H````1`````L``````````````````*]P````10````L`````````````
M`````*]X````1@````L``````````````````*^`````2`````L`````````
M`.OO\'``)+D$``^G^_]@XP#P```DP.4```6RP.4``!\OZ^_Q$``$!_[C$/`X
M`"3`$```2GW2!_`P$`CC$!`0``0'\0<`!P`'`,`0``!*?.,0$```!`?Q#1#C
M$!`,`!3`]/___^4`````P!```$IPXQ`0```$!_$-$.,0$`P`%,#T____U0``
M`!C`$```2F3C$!````0'\0T0XQ`0#``4P/3____%````,,`0``!*6.,0$```
M!`?Q#1#C$!`,`!3`]/___[4```!(P!```$I,XQ`0```$!_$-$.,0$`P`%,#T
M____I0```&#`$```2D#C$!````0'\0T0XQ`0#``4P/3___^5````>,`0``!*
M-.,0$```!`?Q#1#C$!`,`!3`]/___X4```"0P!```$HHXQ`0```$!_$-$.,0
M$`P`%,#T____=0```*C`$```2ASC$!````0'\0T0XQ`0#``4P/3___]E````
MP,`0``!*$.,0$```!`?Q#1#C$!`,`!3`]/___U4```#8P!```$H$XQ`0```$
M!_$-$.,0$`P`%,#T____10```/#`$```2?CC$!````0'\0T0XQ`0#``4P/3_
M__\U```!",`0``!)[.,0$```!`?Q#1#C$!`,`!3`]/___R4```$@P!```$G@
MXQ`0```$!_$-$.,0$`P`%,#T____%0```3C`$```2=3C$!````0'\0T0XQ`0
M#``4P/3___\%```!4,`0``!)R.,0$```!`?Q#1#C$!`,`!3`]/___O4```%H
MP!```$F\XQ`0```$!_$-$.,0$`P`%,#T___^Y0```8#`$```2;#C$!````0'
M\0T0XQ`0#``4P/3___[5```!F,`0``!)I.,0$```!`?Q#1#C$!`,`!3`]/__
M_L4```&PP!```$F8XQ`0```$!_$-$.,0$`P`%,#T___^M0```<C`$```28SC
M$!````0'\0T0XQ`0#``4P/3___ZE```!X,`0``!)@.,0$```!`?Q#1#C$!`,
M`!3`]/___I4```'XP!```$ETXQ`0```$!_$-$.,0$`P`%,#T___^A0```A#`
M$```26CC$!````0'\0T0XQ`0#``4P/3___YU```"*,`0``!)7.,0$```!`?Q
M#1#C$!`,`!3`]/___F4```)`P!```$E0XQ`0```$!_$-$.,0$`P`%,#T___^
M50```EC`$```243C$!````0'\0T0XQ`0#``4P/3___Y%```"<,`0``!)..,0
M$```!`?Q#1#C$!`,`!3`]/___C4```*(P!```$DLXQ`0```$!_$-$.,0$`P`
M%,#T___^)0```J#`$```22#C$!````0'\0T0XQ`0#``4P/3___X5```"N,`0
M``!)%.,0$```!`?Q#1#C$!`,`!3`]/___@4```+0P!```$D(XQ`0```$!_$-
M$.,0$`P`%,#T___]]0```NC`$```2/SC$!````0'\0T0XQ`0#``4P/3___WE
M```#`,`0``!(\.,0$```!`?Q#1#C$!`,`!3`]/___=4```,8P!```$CDXQ`0
M```$!_$-$.,0$`P`%,#T___]Q0```S#`$```2-CC$!````0'\0T0XQ`0#``4
MP/3___VU```#2,`0``!(S.,0$```!`?Q#1#C$!`,`!3`]/___:4```-@P!``
M`$C`XQ`0```$!_$-$.,0$`P`%,#T___]E0```WC`$```2+3C$!````0'\0T0
MXQ`0#``4P/3___V%```#D,`0``!(J.,0$```!`?Q#1#C$!`,`!3`]/___74`
M``.HP!```$B<XQ`0```$!_$-$.,0$`P`%,#T___]90```\#`$```2)#C$!``
M``0'\0T0XQ`0#``4P/3___U5```#V,`0``!(A.,0$```!`?Q#1#C$!`,`!3`
M]/___44```/PP!```$AXXQ`0```$!_$-$.,0$`P`%,#T___]-0``!`C`$```
M2&SC$!````0'\0T0XQ`0#``4P/3___TE```$(,`0``!(8.,0$```!`?Q#1#C
M$!`,`!3`]/___14```0XP!```$A4XQ`0```$!_$-$.,0$`P`%,#T___]!0``
M!%#`$```2$CC$!````0'\0T0XQ`0#``4P/3___SU```$:,`0``!(/.,0$```
M!`?Q#1#C$!`,`!3`]/___.4```2`P!```$@PXQ`0```$!_$-$.,0$`P`%,#T
M___\U0``!)C`$```2"3C$!````0'\0T0XQ`0#``4P/3___S%```$L,`0``!(
M&.,0$```!`?Q#1#C$!`,`!3`]/___+4```3(P!```$@,XQ`0```$!_$-$.,0
M$`P`%,#T___\I0``!.#`$```2`#C$!````0'\0T0XQ`0#``4P/3___R5```$
M^,`0``!'].,0$```!`?Q#1#C$!`,`!3`]/___(4```40P!```$?HXQ`0```$
M!_$-$.,0$`P`%,#T___\=0``!2C`$```1]SC$!````0'\0T0XQ`0#``4P/3_
M__QE```%0,`0``!'T.,0$```!`?Q#1#C$!`,`!3`]/___%4```58P!```$?$
MXQ`0```$!_$-$.,0$`P`%,#T___\10``!7#K;_`P`"3C\/](_W'C,/"H`"3C
M0/"@`"10(/"T04#PH$$P\*A!(/"TP.7___YLQ$@``$?9Q"@``$?2N00`-,#E
M___]`<08``!'GI4`$`"G=``?P.7___W'Q"L``%`TN0(`(J=T``>G*0`!P.7_
M__Y[P.7___[8Q!@``$>9XR`0```6P.7___]/D@`J(<2X``!'CN,@L```%L#E
M____1)8")(KC(+```!;`Y?___SQ8$/"TE@$DBNPA``4`V+D4`"+K(@`#``W`
MY?___HWCL/"H``3C$+````3C$"```"3`$```'*+C$"`(`"180/"TQ!@``$>U
MXQ`@$``D$D3`$```')7C$"`8`"2G.``!P!```$_2Q"L``$_+Y4P0```$IUD`
M`!@4N?+0$Z=;``&G%@!J[!0`!`#8ITH``[D4`!'K$0`#``WC$2_X_W&Y!`!2
MY4@0````IVD``+D4`$3`,```!(+$*```3Z_`Y?___-P8LA(BIW0`"<0H``!/
MI<#E___^$ABRQ"@``$^>P.7___U[P"```!LKP.4```&AN0(`(J=T`"'`$```
M3XKC$!````*G=``+P"```!KQP.4```&/Q"L``$]\P!```$]YXQ`0```"IX0`
M",0H``!/<<#E```-'L0H``!/;\#E___^S,#E___[>;D4`"OK;_#H``0'_NL%
M``,`#>PU``0`V+D$`&"Y%``SXP:P```$ZS,``P`-XP,O^/\DI_3_@0<'!P<'
M![D$`"_`,````!+C,#```!BG^_]@IPD``.,`\```),#T````"0<'!P<``(F(
M!P<'!T%`(`C$6```1I[K;_`P`"3C\/]8_W'$:```1HGE2/"@``#C,"`$`!3$
M*```1G3`Y?___0D'!P<'P!```$;DP"```$;AN2``$J>$``K$&```1G:Y`@`1
MIX0``P?Q!_X'!\`P``!&T,`0``!&S;D)`!/K$0`#``KK,0`_``RY"``QZS,`
M`0`*N0(`,Z>$``W$&```1FVY`@`1IX0`!L`@``!&L@?Q!_X'!\`0``!&K)4`
M$``'?NNO\%``),`0``!&3^/P_V#_<>,0$````J>$``C$*```1ES`Y?___/7`
ML```1$K`H```1$NY"0"KZZH``P`*IZO__\08``!&B;DA`!JG1``<P.7___^:
MP!```$83XQ`0```"IX0`",`@```Y$\#E___[(,`0``!&;9(!$`#KK_#P``0'
M_J<;``'$&P``1F;K$0`#``WC$;````0-X:?T_],'!P<'Z^_P<``DX_#_8/]Q
MZ^_Q$``$!_X'!P<'P!```$7XXQ`0```"IX0`%,`P``!&2,`@```XW>OO\'``
M)./P_V#_<<#E___\I.OO\1``!,#T____7@<'!P<'!^OO\'``)./P_V#_<>OO
M\1``!`?^!P<'!^MO\#``)./P_V#_<;D"`(*GA`!,Q!@``$6ZXV`0```"IX0`
M1+D$`$CC$$```)02$:=T`#`;2+D$`'.Y!`"FN10`M..0H````J>$`!ZY!`!+
MN00`..,@H```!,#E___[/Q(BIW0`'T$;D`"5/1``IW0`&;D)`*9!FY`!ZZH`
M`P`*4*!P`+D$`"GK;_#0``0'_J<>`#VGA/_004!``:?T_\9!H*`(I_3_SZ>9
M``"G]/_LZ^_P<``DLD\`$.L1`"``#;)/`!'C\/]0_W%!,/"DT@?PJ!`HP.7_
M__^6LD\`$.L1`"``#;)/`!'5!_"H$"BGA``%P.7___U3Z^_Q(``$!_[KK_!0
M`"2R3P`0X_#_4/]QZQ$`(``-N00`LK)/`!%!H/"DT@?PJ!`HN00`.KD$`"O`
MY?___VBY`@`BIW0`$;)/`!#K$0`@``VR3P`1U0?PJ!`HIX0`'\#E___](>,0
M\*0`%,0H``!%$^L1``,`#>,0(```".,@$`@`!.,@$```)+D"`"*GA/_201`0
M"*?T__3KK_$```0'_NMO\#``)+)/`!#C\/]0_W'K$0`@``VR3P`1N00`HKD$
M`+/2!_"H$"B5/3``IW0`!$&P,`&G"```N00`&Z>9``"R7@"1IQ3__KD)`)M!
M,/"DN00`*L#E____"KD"`"*GA``RIP@``*<9``"Y!``RLEX`$Z<4__ZY"0`2
MN2$`&:=$`(NG&0``XS&P``"00C$@`*<;``&Y`@`SIW3_]Z<H``"R3P`0N10`
M(NL1`"``#;)/`!'5!_"H$"BGA`#-P.7___RBQ!@``$27XW`0```$IQD``!B!
MIQL``>LA``,`#>,B?_C_`J=T__?L*``"`-C`$```3/FY%``BXQ`0```2ZR(`
M`P`-IX0`%[D$`#*Y!``GP.7___D8Q!@``$1MXR`0```DN0(`(J=T`".G*/__
MI_3_N<`0``!,U^5,$````<#E___YX;D"`&*GA/_QN10`2+D$`#?K1``#``W`
MY?__^>/$&```1$CC8!```"2Y%``8Q"@``$1`IQL``>,@(```!.L1``,`#4$1
M(`#E2!````!0@/"DN00`&N,@$```E!(BIX0`!J<N`#VG=`!-N0D`&KD4`!'$
MB```1![C</"D`!1!*1`"ZW<``P`-XW"````(P.7___F8XR!P```DN0(`(J>$
M_Z7C$/"D`!3C((````3K$0`#``WC(2````3C$*```)!"$"``0:"@`4$P(`'`
M&P```/^GA``&IQX`/:=T`!>2/2``IQD``.,AL```D$(A,`"G&P`!N0(`(J=T
M__>G]/\O01`0`:?T_ZFY!``CI_3_U^MO\.``!`?^!P<'!P<'ZW_P.``DLD\`
M$./P_LC_<>L1`"``#;)/`!&Y`@"BT@?Q,!`HIX0`(I4`H`"GA``>P.7___@H
MN0(`@J>$`!=!</"@N00`*,#E___XW;D"`"*G=``;N00`*,#E___Y=+D$`"K`
MY?__^M^R3P`0ZQ$`(``-LD\`$=4'\3`0**>$`&S`Y?__^Y!!L"`3P!```!=/
MIP@``+D$`"NR70`2IQ3__J>$_]'`$```%T.Y!``KLET`$J<4__ZGA/_&N00`
M&J<I``"Y!``[LEX`(:<4__ZG&0``N0D`*K)>`!.G%/_^N0D`&QHAIRH``KD4
M`"+`Y?__^-JY!`!;N00`DKD$`$K`,```%QC`Y?__^PZY!``WN00`*<#E___Z
MQZ<N__^Y!``IIX0`%5@0\+C`&P``\`"G'D``IW0`#,#E____9;D$`"G`Y?__
M^J"G]/]^P.7___B;I_3_]NM_\7``!`?^!P<'![)/`!#K$0`@``VR3P`1Z[_P
M6``DX_#^R/]QN00`LD$P\*#2!_$P$"C`Y?__^,P2(J=T`"X8$E@@\+C`*P``
M\`"G+D``IX0`!\(M``"@`*=T``ZG.0`"N00`*\#E___WLQ`2IQK__X@0`!^Y
M%``ALD\`$.L1`"``#;)/`!'5!_$P$"BGA``)P.7___K=IQ@``*?T_^WKO_&0
M``0'_@<'!P?K[_!P`"3$&```0L'C\/]@_W'C(!```!;`Y?__^G3`4```-3C$
M2```0L;`,```%H7K[_$0``3`]/__^D4'!P<'ZV_P,``DX_#_6/]QQ+@``$*>
MXR"P```6P&```!?4P.7___I1P.7____.XR"P```6P.7___I(N00`5N5(\*``
M`,!````&W,`P```69<#E___W:NMO\-@`!`?^!P<'!P<'ZV_P,``DLD\`$./P
M_U#]<>L1`"``#>,@\*@"<;)/`!'2!R``$"A!L/"FP&```!9.P.7___>(P$``
M`!9*N00`4J<Y$`&Y!``KP.7___<LIR[__Z=T`!BGN0``LD\`$.,P\*@"<>L1
M`"``#;D$`"NR3P`1U0<P`!`HIX0`2\#E___Z0A(B["`0`"!QIT3_YN.@\*<!
M<:=)$`"Y!``ZN00`*\#E___XL+D$`((2(J=$_]6G*@`!N10`(L#E___WI+D"
M`+*GA/_*N10`F+DA`+JGI``&N>B0&[EA0*&Y(0"ZI\0`!KGHD!JY84"QN00`
M2;D$`#KL@!`!('*Y!``KP.7___G201FP`)(`$`"G]/^HZV_PX`($!_X'!\#T
M____=`<'ZV_P,``DLD\`$./P_L#^<;D$`++K$0`@``WC(/$X`7&R3P`1N00`
M@]('(``0*,`@```5Q,#E___\8J<Y`"^Y!`"2N00`*\#E___W_;D"`"*GA``>
MN00`.\`@```5M,#E___\P;)/`!#C,/$X`7'K$0`@``VY!``KLD\`$=4',``0
M**>$`+#`Y?__^:VG"```N00`&[D$`"BGJ0``P#```!6908#Q.+)>`*&G%/_^
M07#PJ!NKP.7___DVIZH``;D"`"*GA/_)E0`@`,`0```53[GB@"&Y`@"9IX0`
M&*<(``"Y!``2N00`.;)=`!.G%/_^IW0`#,`P```5;:<I``#`Y?__^1&G]/_=
MIP@``*<9``"Y!``RLEX`$Z<4__X;$KD4`#'C,R___W&5+S``IX0`(AH:IQX/
M_Z<D_X_CL/"@`"2Y!`!2P&```!5&P$```!6VISD0`+D$`"C`Y?__]A2G*@`!
MPB\``!``I\0`#J?T``&G&O__N10`,4$S(`"2`#``I_3_S[D$`#>Y!``HP.7_
M__BJ$B*G=/^P6!#PP,`;``#P`,(=``"``*=T_Z:G.0`!N00`*,#E___UUA(B
MIW3_G+D$`#C`(```%/[`Y?___`NY!``HP.7___;FN00`LJ?T_T/K;_%P`00'
M_@<'!P<'![D$`!+C,!```)02,Z=T``,'_D$0$`&G/@`ON>*`(:?T__,'!P<'
M!P>Y`@`RIX0`!I4`,`"G=``(P"```!2@P/3___:YN00`(Z<(``"G&0``LEX`
M$J<4__ZYZ3`AXT`?__]QN2$`-*<D``:G/___IW0`!*<I``&G)P`4N2``-*=T
M`":5+S``IX3_V<`@```4JZ?T_]?C0$___W&G]/_NE2]``*>$__FYZ3`4XR!/
M__]QN2$`,J<I``&YXC`2XR!/__]QE2]``*=T`#BYZ3`4XR!/__]QN2$`,J<D
M``:G/___IW0`!*<9``'C0$___W&G%P`JN0D`0^P4``(`V<(>```0`*<D`":G
M2P`!P"```$#CZ^_P<``DX_#_8/]Q[$`0`"!QP.7___;WP"```$#4Z^_Q$``$
M!_ZY!`!"IQ?_P:?T_YZ5+T``IX3_T:?T_]2G*0``!_X'!P<'LD\`$.L1`"``
M#;)/`!'K[_!P`"3C\/\P_W'`(```%#C2!_#($"C`$```,I_2(?"F$`#`Y?__
M^N?`(```%"[`Y?__^N'`(```%"S`Y?__^MO`(```%"O`Y?__^M7`(```%"G`
MY?__^L_`(```%"O`Y?__^LG`(```$_W`Y?__^L/`(```%"7`Y?__^KW`(```
M%"3`Y?__^K?`(```%"/`Y?__^K'`(```$^K`Y?__^JO`(```%!S`Y?__^GVY
M`@`RIX0`",`@```4",#E___ZY\`@```4%<#E___Z;;D"`#*GA``(P"```!04
MP.7___K7P"```!04P.7___I=N0(`,J>$`"#`(```$[7`Y?__^L?`,```%!O`
M(```$\S`Y?__^KZR3P`0ZQ$`(``-LD\`$=4'\,@0**>$`"7`Y?__]Z_`(```
M$_3`Y?__^C6Y`@`RIX0`!\`@```3NZ?T_]BG20`*P#```!/L02#PM\#E___U
M-A(BIW3_SD$P\,&G]/_LZ^_Q0``$!_[$'0``/]"G'O__IW0`+^OO\'``),`@
M```3E^/P_V#_<<#E___Z!+D"`"*GA``;XQ`@``"0N0(`$:>$`!3`%P```#"Y
M`P`1[!$_OP%5Q!\``#^JQ"P``#^GZ^_Q$``$!_ZG&```I_3_],0L```_G`?^
MZ^_P<``DX_#_8/]QP.7___=:P.7___67N0(`(J>$``7C("````3K[_$0``0'
M_@<'ZV_P,``DN00`LN/P_V#_<<`@```3B,#E___YN;D$`#NY`@!BIX0`!I4`
M8`"G=``+P"```!-XZV_PT``$P/3___H:P.7___47N0(`(J=T`"RG"```N00`
M&[D$`#:R7@`AIQ3__J<9``"Y"0`KLEX`$Z<4__ZY"0`602(0`L#E___T>L`P
M```38KD$`*+`4```$NFY!`!+P.7___:MN00`.J?T_\CK;_#0``0'_@<'!P?K
M;_`P`"2R3P`0ZQ$`(``-LD\`$>/P_ACW<;D$`*+C(/'@"''2!R``$"C`$```
M/N/`(```$K/2#_"P$`#2!_#`$!#`$```/N/2+_#@$`#`$```/O72#_#($`#2
M!_#8$!#`Y?__^3RY`@"RIX0`))4`L`"GA``@P.7___]MN00`*\#E___T@+D$
M`+*R3P`0XS#QX`AQZQ$`(``-N00`*[)/`!'5!S``$"BGA`+3P.7___:*P.7_
M__\WN0(`LJ=T`"=!D/#(XQ"0```"IW0`!\"P```2V:?T`!OC()````3`Y?__
M^/VY`@`2IW0`!J>;``BG]/_JE0`0`*>$__K`Y?__]$*Y`@"RIX3_\Z<(``"Y
M!``;IRD``+)>`"&G%/_^N0D`*^LB``$`#:<K``'`Y?__\\JY!`"2N00`@N-`
ML```E!)$IW0`D4&P\.#C<+````*GA``=XR"P```$P.7___B_N0(`@J>$`)"5
M`(``IX0`C,#E___["!(BIX0`AKD$`"C`Y?__]`"Y!`!R0;#PL+D"`'>G=``+
MXX"P```"IX0`!I4`@`"G=`!TIP@``+D$`!>GN0``LEX`L:<4__ZY!``IIQD`
M`+D)`+>R7@`2IQ3__KD)`!D:L:>Z!`2Y%`"[N00`*\#E___S;^.0\*``)+D$
M`(+`4```$=^Y!`!'P#```!),P&```!)&P.7___6<ISD!P+D$`"C`Y?__]36G
M+O__IW0`2L#E___U'EA@(`"G;@`1IX0`0<08```]H;D4`&:Y!`!8XT"@```$
MP#```!(JXR`0```$P.7___25I[D``*?T_Q6Y!``HN10`1,`P```2#D&PL`%!
M@(`"P.7___5CI_3_7:>[``BG]/]AXR"P```$P.7___IW$B*GA``)N00`*,#E
M___S;[D$`'*GNP`(I_3_;T$P\1"Y!``HP.7___-"&)(2(J>$`!7$&```/5>Y
M!`!8XT"@```$P#```!(`XR`0```$P.7___1-I_3_N%@0\2C`&P``\`"G'D``
MIW3_YEAP\2S`Y?__]6T9<J=T_]Y8$/$HP!L```'_IQX!P*=T_]6Y!``KP.7_
M__+,N00`LL`@```1_L#E___WT+D"`"*G=`#-XW"@```$IP@``*<9``"Y!``G
MLEX`$J<4__ZY"0`7IQX``Z?$`$2Y%``AXS)__/]QP"```!'?LET`(Z<4__ZG
M=``VIQX`!*>$``VG&O_\N10`$>,1?___<94O$`"G=``GXR"@"``"IX0`(J<(
M``"G&0``N00`,K)>`!.G%/_^N0D`$L(>`````Z?$`!'C(2_\_W'`$```$;&R
M70`2IQ3__J=T``7C<*`(``3`Y?___6`2(J=T`-6Y!``GISD``,#E___RSKD$
M`*(8<A(BIX0`R*=)``*G.?_NP.7___'A06#QX*=)``:Y!``VN00`*L#E___S
MYI4`\>"G=`!BE4/QX:=T`%Z50?'BIW0`6I5#\>.G=`!6E4CQY*=T`%*51?'E
MIW0`3J=)``*G.?_&N00`*L#E___QM:=)`"FY!``VN00`*L#E___SO,`0```1
MR<!0```0CN,0\*``)+D$`$C`,```$4ZY!``KP.7___1)N00`*,#E___S]+D$
M`#O`(```$&K`Y?__]WRY!``KP.7___T_I_3]V>-PH```!,#E___R3[D$`#*Y
M!``GP.7___IXN0(`<J=T_RFG]/\DITD``*<Y``"Y!``JN10`=\#E___Q9\#E
M```.9+D$`)*E3X``N00`-KD$`"?`Y?__\VD2(J<D`"NY!``G0:#QH\#E___S
M/[D$`#FY!``J09#QMZ=Y`!2Y!`!IP.4```\JXT"@``"0N00`*<`P```0CJ>K
M``&GFP`"P.7___/CIW?_\9(`\=^G]/^#N10`0KD$`#:Y!``IP.4```Y<I_3_
MPL`P```09L`@```0)<#E___W"<"@```1-L#E___Q(\`0```1,+D$`&+C$/"@
M`"3`4```#_"Y!`!(P#```!"[N00`*\#E___SKJ<Y`<"Y!``KP.7___-'IR[_
M_Z=T_US`Y?__\S!8$"``IQX`$:=T_U.GF@`!P.7___#UN10`&;D$`&+CH/"H
M`"3C$/"@`"3`4```#\"Y!`!(P#```!"2N00`*\#E___S?J?T_]#K;_(8"`0'
M_@<'ZV_P,``DX_#_8/]QQ+@``#NBXR"P```6P.7___-8N00`HN,@L```%L#E
M___S4-(`(+F@N,`@```/I<#E___V([D"`"*GA``*E3$@`*=T``:5`"`!IX0`
M!<#E___[/,08```[>>,@$```%L#E___S+Z=9``NG20`!P#```!!AP.7___&5
MN0(`(J=T`$W$J```.V+C(*```!;`Y?__\QBG60`#ITD``<`P```03<#E___Q
M?KD"`+*G=`"YQ*@``#M+XR"@```6P.7___,!IUD``Z=)``'`,```$#K`Y?__
M\6>Y`@"RIX0`[,`@```/,,#E___UR;D"`)*GA`#%XR"@```6P.7___+CXQ"P
M$``$N00`2>,P$```!,#E___Q:*?T`,_C$"`0``2GN``!XX`0*``$Q)@``#L/
M[*O__P#86""0`,:]``!#BZ>D`!2Y%@`BP.7___*\IUD``+D4`$JY!``XP.7_
M__!3N0(`<J=T`!'$'0``0W2G&O__&:&G=/^(I[@``<2H```ZYJ?T`$;$*```
M0V&Y%``;ZQ$``P`-XV$@```$XQ!P```$6"`0#,`K`"`$`*<N!`"G=``1XR`0
M$``$IP@``+)=`":G%/_^IW3_T:>Z``&G]/^QXR"0```6P.7___)TIUD``J=)
M``#C,'````3`Y?__\JJG]/_DN18`(J>Z``'`Y?__\F&Y!``XP.7__^\L6""@
M`,:]``!#'Z=$_^^G]/\TXR"@```6P.7___)-XQ"P$``$P$````^$XS`0```$
MP.7___#1XQ"P$``$XQ`0```$D4`0#:>$_R_C(*```!;`Y?__\C'C$+`0``3C
M,!````3`Y?__[]BG]/\>P.7___?SN0(`DN,@H```%J>$`&#`Y?__\AGC$+`0
M``2Y!`!)XS`0```$P.7___">N00`*<#E___QR<2X```Z2N,@L```%L#E___R
M`+D$`*+C(+```!;`Y?__\?BG20`!P#````\TP.7__^[PP$````\YN00`,KD$
M`"K`Y?__\';C(+```!;`Y?__\>"2`""YP"````X6P.7___2TQ"L``$*AN0(`
M(J=T`"/$*```0I+`Y?__^SO$*P``0I2Y`@`BIW0`%L`@```/$,#E___N_L#E
M___QN\0X``!"?.,0L!``!.-`,```!*?T_M2G.0'`Q"@``$)WP.7___%8IRX`
M$:>$`!OL$@`!`-C"'P````&GQ``3Q!@``$)=N00`4L1(``!"8.,P$```!,`@
M```.[L#E___NR^MO\-``!`?^ZZ_P4``DX_#_8/]QN00`LL#E___XZ,#E___X
MT;D$`*+`Y?__^CP2(J>$`!ZY`@"[IX0`&I4`L`"GA``6P#````X=N00`*L#E
M___OL;D@`**G=``*N00`*^NO\/``!,#T___UU>NO\/``!`?^!P<'![)/`!#K
M$0`@``VR3P`1ZV_P,``DIUD`"./P_-#_<:>Y``#2!_,H$"A!$/"HN00`,>-+
M(#@`!.L$`"``#.,`,```),!*`````.-`,`@`)*>[``BG.P`0IU?_[:=)`$#C
M,!!H``3C,!!``(+C,!`0`(+C,!```(+L4R"_(57L4R`^`5;C4!"``"2G&P`(
MIT?_Z>,0\*@`!,(:6H)YF>,0("``".-0(```!..0(!``!..@(`@`!..P(!@`
M!.Q%(+\E5>Q%(#H%5KD(`$&YY[`9N8``&KF"`!OK.@`"``RY"`!![#H`(1Y6
MXQ#PL``$[&,@OP!5PAI:@GF9N>=@B;D(`!NY@`"%N8(`B;D(`!C`2@````#K
MA``;``SLA"`Z!5:Y"`"!ZQ4``@`,[!4`(1Y6N><0`^,P\+@`!+F```3".EJ"
M>9FY@@`&N0@`.;D(`##`B@````#L<2"_`%7K"``;``SL""`Z!5:Y"``#ZS0`
M`@`,[#0`(1Y6N><P0>,0\,``!+F``$C"&EJ">9FY@@!'N0@`%KD(`!3`"@``
M``#LTR"_`%7K0``;``SL0"`Z!5:Y"`!!ZQ@``@`,[!@`(1Y6N><0@^,P\,@`
M!+F``(#".EJ">9FY@@"-N0@`-[D(`#C`2@````#L82"_`%7KA``;``SLA"`Z
M!5:Y"`"#ZS```@`,[#``(1Y6N><P`>,0\-``!+F```3"&EJ">9FY@@`&N0@`
M';D(`!#`B@````#L<R"_`%7K"``;``SL""`Z!5:Y"``!ZQ0``@`,[!0`(1Y6
MN><00^,P\-@`!+F``$C".EJ">9FY@@!'N0@`-KD(`#3`"@````#LT2"_`%7K
M0``;``SL0"`Z!5:Y"`!#ZS@``@`,[#@`(1Y6N><P@>,0\.``!+F``(#"&EJ"
M>9FY@@"-N0@`%[D(`!C`2@````#L8R"_`%7KA``;``SLA"`Z!5:Y"`"!ZQ``
M`@`,[!``(1Y6N><0`^,P\.@`!+F```3".EJ">9FY@@`&N0@`/;D(`##`B@``
M``#L<2"_`%7K"``;``SL""`Z!5:Y"``#ZS0``@`,[#0`(1Y6N><P0>,0\/``
M!+F``$C"&EJ">9FY@@!'N0@`%KD(`!3`"@````#LTR"_`%7K0``;``SL0"`Z
M!5:Y"`!!ZQ@``@`,[!@`(1Y6N><0@^,P\/@`!+F``(#".EJ">9FY@@"-N0@`
M-[D(`#C`2@````#L82"_`%7KA``;``SLA"`Z!5:Y"`"#ZS```@`,[#``(1Y6
MN><P`>,0\0``!+F```3"&EJ">9FY@@`&N0@`';D(`!#`B@````#L<R"_`%7K
M"``;``SL""`Z!5:Y"``!ZQ0``@`,[!0`(1Y6N><00^,P\0@`!+F``$C".EJ"
M>9FY@@!'N0@`-KD(`#3`"@````#LT2"_`%7K0``;``SL0"`Z!5:Y"`!#ZS@`
M`@`,[#@`(1Y6N><P@>,0\1``!+F``(#"&EJ">9FY@@"-N0@`%[D(`!C`2@``
M``#L8R"_`%7KA``;``SLA"`Z!5:Y"`"!ZQ```@`,[!``(1Y6N><0`^,P\1@`
M!+F```3".EJ">9FY@@`&N0@`/;D(`##`B@````#L<2"_`%7K"``;``SL""`Z
M!5:Y"``#ZS0``@`,[#0`(1Y6N><P0>,0\2``!+F``$C"&EJ">9FY@@!'N0@`
M%KD(`!3`"@````#LTR"_`%7K0``;``SL0"`Z!5:Y"`!!ZQ@``@`,[!@`(1Y6
MN><0@^,P\2@`!+F``(#".EJ">9FY@@"-N0@`-[D(`#C`2@````#L82"_`%7K
MA``;``SLA"`Z!5:Y"`"#ZS```@`,[#``(1Y6N><P`>,0\3``!+F```3"&EJ"
M>9FY@@`&N0@`';D(`!#`B@````#L<R"_`%7K"``;``SL""`Z!5:Y"``!ZQ0`
M`@`,[!0`(1Y6N><00^,P\3@`!+F``$C".EJ">9FY@@!'N0@`8[D(`&3`"@``
M``#LT2"_`%7K0``;``SL0"`Z!5:Y"`!&ZV@``@`,[&@`(1Y6N>=@@>,0\4``
M!+F``(#"&EJ">9FY@@"-N0@`<;D(`'CL-""_`%7K@P`;``SL@R`Z!5:Y"`"'
MZW```@`,['``(1Y6N>=P!KF"`$#C`/%(``3""F[9ZZ&Y"`#0N1H`U.P8(+\`
M5>L!`!L`#.P!(#H%5KD(``WKTP`"``SLTP`A'E;C,/%0``3".F[9ZZ&Y&@`V
MN>?09[F"`(;L0""_`%6Y&@`XZV$``@`,N00`@^QA`"$>5N,0\5@`!,(:;MGK
MH;D:`!>YYV!]ZS0`&P`,N8(`!^PT(#H%5NMT``(`#+D(`#CL=``A'E;L@R"_
M`%7C0/%@``3"2F[9ZZ&Y&@!-N>=PUKF"`#VY&@`0N1H`0[D$``&Y!``TZQ@`
M&P`,Z]@``@`,[!@@.@56[-@`(1Y6N0@`$.P!(+\`5>M``!L`#.Q`(#H%5KD(
M`$/L-""_`%7C@/%H``3"BF[9ZZ&Y&@"&N>?09[F"`!:Y&@"!ZV```@`,N00`
M&.Q@`"$>5N,`\7``!,(*;MGKH;D:``>YYV!]N8(`1^N#`!L`#+D:``3L@R`Z
M!5:Y!`!`N0@`@>MS``(`#.P8(+\`5>QS`"$>5N,P\7@`!,(Z;MGKH;D:`#VY
MYW#6N8(`C>L!`!L`#+D:`#CL`2`Z!5:Y!`"#N0@`!.O1``(`#.Q`(+\`5>S1
M`"$>5N,0\8``!,(:;MGKH;D:`!:YY]!GN8(`!NLT`!L`#+D:`!#L-"`Z!5:Y
M!``!N0@`..MD``(`#.R#(+\`5>QD`"$>5N-`\8@`!,)*;MGKH;D:`$>YYV!]
MN8(`-^L8`!L`#+D:`$/L&"`Z!5:Y!``TN0@`$.MX``(`#.P!(+\`5>QX`"$>
M5N.`\9``!,**;MGKH;D:`(VYYW#6N8(`'>M``!L`#+D:`('L0"`Z!5:Y!``8
MN0@`0^O0``(`#.PT(+\`5>S0`"$>5N,`\9@`!,(*;MGKH;D:``:YY]!GZX,`
M&P`,N8(`1NR#(#H%5NMC``(`#+D(`('L8P`A'E;L&""_`%7C,/&@``3".F[9
MZZ&Y&@`WN>=@?;F"`(>Y&@`$N1H`.+D$`$"Y!`"#ZP$`&P`,[`$@.@56N0@`
M!.Q`(+\`5>LT`!L`#.PT(#H%5KD(`#CK@0`"``SL@0`A'E;C$/&H``3"&F[9
MZZ&Y&@`=N>>`UKF"``WL<R"_`%6Y&@`0Z]0``@`,N00``>S4`"$>5N-`\;``
M!,)*;MGKH;D:`$:YY]!HN8(`-NL7`!L`#+D:`$/L%R`Z!5:Y!``TN0@`$.MG
M``(`#.P!(+\`5>QG`"$>5N-P\;@`!,)Z;MGKH;D:`'BYYV"-N8(`&.M``!L`
M#+D:`''L0"`Z!5:Y!``7N0@`0^N```(`#.PT(+\`5>R``"$>5N,`\<``!,(*
M;MGKH;D:``VYYX#6N8(`3>MS`!L`#+D:``3L<R`Z!5:Y!`!`N0@`<>O3``(`
M#.P7(+\`5>S3`"$>5N,P\<@`!,(Z;MGKH;D:`#:YY]!HN8(`=NL!`!L`#+D:
M`#?L`2`Z!5:Y!`!SN0@`!.MA``(`#.Q`(+\`5>QA`"$>5N,0\=``!,(:;MGK
MH;D:`!BYYV"-ZS0`&P`,N8(`".PT(#H%5NN$``(`#+D(`#?LA``A'E;L<R"_
M`%7C0/'8``3"2F[9ZZ&Y&@!-N>>`UKF"`#VY&@`0N1H`0[D$``&Y!``TZQ<`
M&P`,[!<@.@56N0@`$.P!(+\`5>M``!L`#.Q`(#H%5KD(`$/K-P`"``SL-P`A
M'E;C</'@``3">F[9ZZ&Y&@!VN><P:+F"`!:Y&@!QP$H`````N00`%^S3(+\`
M5>MT`!L`#.QT(#H%5KD(`''K$``"``SL$``A'E;L82"_`%6YY&`-N8$`,;F`
M`#2Y@0`PXP#QZ``$P@J/&[S<N1H`"+D(`##`>@````#K!P`;``SL!R`Z!5:Y
M"``#ZS0``@`,[#0`(1Y6[(,@OP!5N>8P0;GD@!:Y@`!'N8$`0>,0\?``!,(:
MCQN\W+D(`!VY"``4P`H`````ZT``&P`,[$`@.@56N0@`0>L7``(`#.P7`"$>
M5NS1(+\`5;GF$'.YY-`XN8``<+F!`'/C,/'X``3".H\;O-RY"``VN0@`-\!*
M`````.MT`!L`#.QT(#H%5KD(`'/K,``"``SL,``A'E;L8R"_`%6YYC`!N>1@
M';F```2Y@0`!XQ#R```$PAJ/&[S<N0@`&+D(`!#`>@````#K!P`;``SL!R`Z
M!5:Y"``!ZQ0``@`,[!0`(1Y6[($@OP!5N>800[GD@#:Y@`!'N8$`0^,P\@@`
M!,(ZCQN\W+D(`#VY"``TP`H`````ZT``&P`,[$`@.@56N0@`0^LW``(`#.PW
M`"$>5NS3(+\`5;GF,'&YY-`8N8``<+F!`''C$/(0``3"&H\;O-RY"``6N0@`
M%\!*`````.MT`!L`#.QT(#H%5KD(`''K$``"``SL$``A'E;L82"_`%6YYA`#
MN>1@/;F```2Y@0`#XS#R&``$PCJ/&[S<N0@`.+D(`##`>@````#K!P`;``SL
M!R`Z!5:Y"``#ZS0``@`,[#0`(1Y6[(,@OP!5N>8P0;GD@!:Y@`!'N8$`0>,0
M\B``!,(:CQN\W+D(`!VY"``4P`H`````ZT``&P`,[$`@.@56N0@`0>L7``(`
M#.P7`"$>5NS1(+\`5;GF$'.YY-`XN8``<+F!`'/C,/(H``3".H\;O-RY"``V
MN0@`-\!*`````.MT`!L`#.QT(#H%5KD(`'/K,``"``S`>@````#L,``A'E;L
M8R"_`%6YYC`!N>1@';F```2Y@0`!XQ#R,``$PAJ/&[S<N0@`&+D(`!#K!P`;
M``SL!R`Z!5:Y"``!ZQ0``@`,[!0`(1Y6[$$@OP!5N>80@[GD0#:Y@`"'N8$`
M@^,P\C@`!,(ZCQN\W+D(`#VY"``XP`H`````ZX``&P`,[(`@.@56N0@`@^LW
M``(`#.PW`"$>5NS3(+\`5;GF,'&YY-`4N8``<+F!`''C$/)```3"&H\;O-RY
M"``6N0@`%\"*`````.MX`!L`#.QX(#H%5KD(`''K$``"``SL$``A'E;L`2"_
M`%6YY`!MN8$`,;F``#BY@0`VXV#R2``$PFJ/&[S<N0@`9+D(`&/`>@````#K
M2``"``SK-P`;``SL2``A'E;L-R`Z!5:YYD"!N0@`-NQD(+\`5;GD8!"Y@`"'
MN8$`@>,0\E``!,(:CQN\W+D(`!VY"``8P#H`````ZX,`&P`,[(,@.@56N0@`
M@>L7``(`#.P7`"$>5NS1(+\`5;GF$'2YY-!&N8``<[F!`'3C0/)8``3"2H\;
MO-RY"`!`N0@`1\"*`````.L#``(`#.MX`!L`#.P#`"$>5NQX(#H%5NPP(+\`
M5;D(`'2YY@!!N>0P';F``$BY@0!!XQ#R8``$PAJ/&[S<N0@`%KD(`!3`>@``
M``#K1P`;``SL1R`Z!5:Y"`!!ZQ@``@`,[!@`(1Y6[($@OP!5N>808+GD@`.Y
M@`!GN8$`8.,`\F@`!,(*CQN\W+D(``VY"``&P$H`````ZV0`&P`,[&0@.@56
MN0@`8.L'``(`#.P'`"$>5NS0(+\`5;GDT'BY@0`0N8``%+F!`!?C</)P``3"
M>H\;O-RY"`!SN0@`<<!J`````.LT``(`#.L6`!L`#.PT`"$>5NP6(#H%5KGF
M,$"Y"``7N8``1NQS(+\`5;GD<`VY@0!`P!H`````XP#R>``$P@J/&[S<N0@`
M@+D(`(3K00`;``SL02`Z!5:Y"`!(XT#PH``D[(0@OP!5ZP8``@`,[`8`(1Y6
M[&`@OP!5N>1@1[F!`#"Y@``QN8$`-.-`\H``!,)*CQN\W+D(`-3K00`"``SL
M00`A'E:Y@@`$N0@`T[D$`!3C0/"@``2Y@@!`XP#RB``$P@K*8L'6ZS@`&P`,
MN0@`<.PX(#H%5KD:`'2Y"``]ZP@``@`,[-,@OP!5[`@`(1Y6N><`@;F"`(.Y
M!`!'XS#RD``$ZWT`&P`,PCK*8L'6['T@.@56N0@`-KD:`#CKC0`"``SLC0`A
M'E;CT/*8``3"VLIBP=:Y&@#1N00`';D(`'2YYX#0[$<@OP!5N8(`?>O4``(`
M#.S4`"$>5NMD`!L`#.QD(#H%5KD$`$WCT/*@``3"VLIBP=:Y&@#0N00`#;GG
M0-BY"`!CN1H`%^PV(+\`5;F"`&WKTP`"``SLTP`A'E:Y!`!QZQ,`&P`,[!,@
M.@56N00`/>/0\J@`!,+:RF+!UKD:`-BY!`"-N><PU+D(`!>Y&@`&['$@OP!5
MN8(`'>O7``(`#.S7`"$>5KD$`&#K!P`;``SL!R`Z!5:Y!`!]X]#RL``$PMK*
M8L'6N1H`U+D$`$VYYW#3N0@`!NQ@(+\`5;F"``WKU@`"``SLU@`A'E:Y&@"!
MZQ8`&P`,[!8@.@56N00`;>/0\K@`!,+:RF+!UKD:`-.Y!``]N0@`&+GG8-?L
M@2"_`%6Y&@!`N8(`'>O8``(`#.S8`"$>5KD$``3K2``;``SL2"`Z!5:Y!`"-
MX]#RP``$PMK*8L'6N1H`U[D$`'VY"`!`N>>`UNP$(+\`5;F"`$WKT``"``SL
MT``A'E:Y&@`QZQ``&P`,[!`@.@56N00`#>/0\L@`!,+:RF+!UKD:`-:Y!`!M
MN><`V+D(`!/L,2"_`%6Y@@`=Z],``@`,[-,`(1Y6N1H`=.M#`!L`#.Q#(#H%
M5KD$`#WCT/+0``3"VLIBP=:Y&@#8N00`C;GG,-"Y"`!'['0@OP!5N8(`3>O7
M``(`#.S7`"$>5KD:`&'K%P`;``SL%R`Z!5:Y!`!]X]#RV``$PMK*8L'6N1H`
MT+D$``VY"``6N>=PT^QA(+\`5;F"`!WKU@`"``SLU@`A'E:Y&@"$ZT8`&P`,
M[$8@.@56N00`;>/0\N``!,+:RF+!UKD:`-.Y!``]N>=@U[D(`$CLA""_`%6Y
M@@!-Z]@``@`,[-@`(1Y6N1H``>L8`!L`#.P8(#H%5KD$`(WCT/+H``3"VLIB
MP=:Y&@#7N00`?;GG@-:Y"``0N1H`-.P!(+\`5;F"`!WKT``"``SLT``A'E:Y
M!`!#ZS``&P`,[#`@.@56N00`#>/0\O``!,+:RF+!UKD:`-:Y!`!MN><`V+D:
M`'&Y"``T[$,@OP!5N8(`/>O4``(`#+D:`&/LU``A'E;K%``;``SL%"`Z!5:Y
M!`!-N0@`%^/0\O@`!.QQ(+\`5<+:RF+!UNLW`!L`#+D:`-CL-R`Z!5:Y"``V
M[&,@OP!5N00`C;GG0-"Y@@`=Z]<``@`,[-<`(1Y6N00`?>/0\P``!,+:RF+!
MUKD:`-"Y!``-N>=PU+F"`#WKU@`"``SLU@`A'E:Y&@"!ZQ8`&P`,[!8@.@56
MN00`;>/0\P@`!,+:RF+!UKD:`-2Y!`!-N>=@U[D(`!CL@2"_`%6Y@@`=Z]@`
M`@`,[-@`(1Y6N1H``^LX`!L`#.PX(#H%5KD$`(WCT/,0``3"VLIBP=:Y&@#7
MN00`?;GG@-:Y"``P[`,@OP!5N8(`/>O0``(`#.S0`"$>5KD:`$'K$``;``SL
M$"`Z!5:Y!``-X]#S&``$PMK*8L'6N1H`UKD$`&VY&@!SN><`V+D(`!3L02"_
M`%6Y@@`=X]#S(``$N1H`8<+:RF+!UKD:`-CK-``;``RY!`"-[#0@.@56N0@`
M-^QS(+\`5>L7`!L`#.P7(#H%5KD(`!;K9``"``S`&@````#L9``A'E:Y!`!&
MN>=`T+F"`#VY"`"AN1H`@\"J`````..@(`@`).LQ`!L`#+D:`+3L,2`Z!5;`
MN@````#CL"`8`"2Y"``XXQ`@(``$N1H`4[D:`!#`6@````#C4"```"3`&@``
M``#C$"`@`"3K9P`"``SL9R`A'E:Y"`"6P)H`````XY`@$``DLD\`$.L1`"``
M#;)/`!'5!_,H$"BGA``%P.7__^7XZV_S8``$!_X'!^OO\'``)*<I`(#C\/]@
M_W'`Y?__XVC`,6=%(P'C,"```"3E2"`H``#`/^_-JXGC,"`(`"3E2"`P``#`
M/YBZW/[C,"`0`"3E3"!X``#`,1`R5';C,"`8`"3`/\/2X?#C,"`@`"3K[_$0
M``0'_@<'!P?K;_`P`"3K%``#``VY!`"BXR`@*``$N0@`$N/P_V#_<<`:````
M`+D$`+2Y(0`AI\0`!>L!H#``>N,0H"@`).L;`!T`#.,0H#``".,0H#``)$&0
MH#CC$*!X`!*GA``TIX@`0!N!&8NY!``IN?*PB[D8`"&Y%`!(N2$`(Z>D``:Y
MZ$`2N6%`,;GH0'.Y(0`CI\0`!+EA0"?`Y?__Y3T8&%H0H'A0$*!XIQX`0*=T
M`%>Y!``J&[C`Y?__\\*Y%`"[N00`-^N+``8`WJ>*``&G&``!$KM!8*!XN?)0
M@:?T`"2G]``!N2$`.:?$``:Y(0`VIT3_^+DA`#E!<#!`IZ0`!KDA`)>G1/_N
MN00`*J>Z_\"Y%`"[TC^0`#``P.7___.0N00`-Z>&_^"Y(0`YI\0`!KGHL!FY
M84`QN2$`.:>D``:YZ+`3N6%`D;D$`$NY!``IP.7__^3A4+"@>.MO\-``!`?^
MZX_P0``DP-```!^!X_#_8/]QXY`P*``$N00`HN.`,#``!.PI.K\]5>P2``$`
MV+D4`")!(C`XDH`@`+D$`+.Y%``AIQX`.$%",#BGQ`!7IR@`0+GY$!*Y%@`Q
MN00`).M%T```!*@D``"G%/_^N00`*\#E___S--<WL#BP..L8`!@`#$(0L'!"
M@+!SZQ@`$``,0A"P<4*0L'?K&``(``Q"$+!RN00`*^L9`!@`#$(0L'3K&0`0
M``Q"$+!UZQD`"``,0A"P=L#E___S"KD$`"O2`Z``L`32`Z`$L`S2`Z`(L!32
M`Z`,L!S2`Z`0L"3KC_#@``3`]/__X_^G*``XN?D0$KD6`#&Y!``DZT70```$
MJ"0``*<4__ZG]/^S!P<'!P<'Z[_P6``DX_#_8/]QP+```"IRXQ"P```$IQ__
M_Z=T``;KO_#X``0'_N.PO_C_<0WAI_3_\0<'!P?K[_!P`"3C\/]@_W'K[_$0
M``0'_@<'!P?K[_!P`"2Y!``/I_O_8.,`\```),#E___EZNOO\1``!`?^````
M````+@`N+@``)7,O)7,`1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN
M=&5R;F%L<SHZ4$%2.CI"3T]4``!E>&4`+W!R;V,O)6DO)7,`4$%27U1%35``
M`%!!4E]04D]'3D%-10``.@`O`%!%4DPU3$E"``!015),3$E"`%!%4DPU3U!4
M``!015),24\``%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1`!005)?0TQ%
M04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?1TQ/0D%,7T1%0E5'``!005)?
M1TQ/0D%,7U1-4$1)4@!005)?5$U01$E2``!005)?1TQ/0D%,7U1%35``4$%2
M7T=,3T)!3%]#3$5!3@``4$%27T-,14%./0``,0!,1%],24)205)97U!!5$@`
M4UE35$5-```E,#)X``!P87(M```E<R5S)7,E<P``)7,Z(&-R96%T:6]N(&]F
M('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``
M)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E
M(')E;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@``4$%42```
M<&%R;```+G!A<@``)7,E<V-A8VAE+25S)7,``"5S)7-T96UP+25U)7,`)7,E
M<W1E;7`M)74M)74E<P``+W1M<```5$5-4$1)4@!435``55-%4@``55-%4DY!
M344``$%21U8``!@`<&5R;```,`!005(Z.E!A8VME<CHZ5D524TE/3@``,2XP
M-#D`56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD``"5S.B!C<F5A
M=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@
M*&5R<FYO/25I*0H``"UE```M+0``979A;"`G97AE8R`O=7-R+V)I;B]P97)L
M("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@
M<V]M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)%!!4E]-04=)0RP@
M)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE*3L*14Y$('L@:68@*"1%
M3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@
M1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I
M<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H
M<7%[4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")]*3L*1FEL93HZ1FEN
M9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL
M("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M
M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ
M5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A
M<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I5
M3DQ)3DL@/3X@,"P**3L*<')I;G0@)'1M<"`B(R$O8FEN+W-H"G@],3L@=VAI
M;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;
M(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX
M/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R(@+B`D=&UP+3YF:6QE;F%M92`N
M("(G"B(["F-H;6]D(#`W,#`L)'1M<"T^9FEL96YA;64["FUY("1C;60@/2`D
M=&UP+3YF:6QE;F%M92`N("<@/B]D978O;G5L;"`R/B8Q("8G.PIC;&]S92`D
M=&UP.PIS>7-T96TH)&-M9"D["F]U=',H<7$H4W!A=VYE9"!B86-K9W)O=6YD
M('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`I"BX@)'1M<"T^9FEL96YA
M;64I.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@
M9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["B1005)?34%'24,@/2`B
M7&Y005(N<&U<;B(["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q=6EE
M="`]("$D14Y6>U!!4E]$14)51WT["FUY("5#;VYF:6<@/2`H"G!A=&A?<V5P
M("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@
M("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE
M>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R
M+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["E]S971?<&%R
M7W1E;7`H*3L*;7D@*"1S=&%R=%]P;W,L("1D871A7W!O<RD["GL*;&]C86P@
M)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["F]P96X@7T9(+"`G/"<L("1P<F]G
M;F%M92!O<B!L87-T.PIB:6YM;V1E*%]&2"D["FUY("1B=68["FUY("1S:7IE
M(#T@+7,@)'!R;V=N86UE.PIM>2`D8VAU;FM?<VEZ92`](#8T("H@,3`R-#L*
M;7D@)&UA9VEC7W!O<SL*:68@*"1S:7IE(#P]("1C:'5N:U]S:7IE*2!["B1M
M86=I8U]P;W,@/2`P.PI](&5L<VEF("@H;7D@)&T@/2`D<VEZ92`E("1C:'5N
M:U]S:7IE*2`^(#`I('L*)&UA9VEC7W!O<R`]("1S:7IE("T@)&T["GT@96QS
M92!["B1M86=I8U]P;W,@/2`D<VEZ92`M("1C:'5N:U]S:7IE.PI]"G=H:6QE
M("@D;6%G:6-?<&]S(#X](#`I('L*<V5E:RA?1D@L("1M86=I8U]P;W,L(#`I
M.PIR96%D*%]&2"P@)&)U9BP@)&-H=6YK7W-I>F4@*R!L96YG=&@H)%!!4E]-
M04=)0RDI.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?34%'24,I
M*2`^/2`P*2!["B1M86=I8U]P;W,@*ST@)&D["FQA<W0["GT*)&UA9VEC7W!O
M<R`M/2`D8VAU;FM?<VEZ93L*?0IL87-T(&EF("1M86=I8U]P;W,@/"`P.PIS
M965K(%]&2"P@)&UA9VEC7W!O<R`M(#0L(#`["G)E860@7T9(+"`D8G5F+"`T
M.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M(#0@+2!U;G!A8VLH(DXB+"`D8G5F
M*2P@,#L*)&1A=&%?<&]S(#T@=&5L;"!?1D@["FUY("5R97%U:7)E7VQI<W0[
M"G)E860@7T9(+"`D8G5F+"`T.R`@("`@("`@("`@("`@("`@("`@("`@("`@
M(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q(")&24Q%
M(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C
M:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q*%5N
M<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN*2D["FUY("1C<F,@/2`H("1F
M=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968[
M"FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N
M*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F
M+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E
M>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`]
M(%]T96UP9FEL92@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ2&5A
M=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(
M96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS
M:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D("1%
M3E9[4$%27U1%35!]("D@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H(B1B
M87-E;F%M921E>'0B+"`D8G5F+"`P-S4U*3L*;W5T<R@B4TA,24(Z("1F:6QE
M;F%M95QN(BD["GT*96QS92!["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]
M"B1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PIB=68@
M/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN86UE+`I].PI]
M"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@
M*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@
M;W(@(21M;V1U;&4["FUY("1I;F9O(#T@9&5L971E("1R97%U:7)E7VQI<W1[
M)&UO9'5L97T@;W(@<F5T=7)N.PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O
M)&EN9F\O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN
M960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?
M=&UP9FEL92!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*<')I;G0@)&9H("1I
M;F9O+3Y[8G5F?3L*<V5E:R@D9F@L(#`L(#`I.PIR971U<FX@)&9H.PI]"F5L
M<V4@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H(B1I;F9O+3Y[8W)C?2YP
M;2(L("1I;F9O+3Y[8G5F?2D["F]P96X@;7D@)&9H+"`G/"<L("1F:6QE;F%M
M92!O<B!D:64@(F-A;B=T(')E860@)&9I;&5N86UE.B`D(2(["F)I;FUO9&4H
M)&9H*3L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D
M.B!C86YN;W0@9FEN9"`D;6]D=6QE(5QN(CL*?2P@0$E.0RD["G)E<75I<F4@
M6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(
M96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I
M;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY
M("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*
M=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T10
M04XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E
M("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL
M96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E
M<75I<F5?;&ES='LD9FEL96YA;65].PI]"FQA<W0@=6YL97-S("1B=68@97$@
M(E!+7#`P,UPP,#0B.PHD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0[("`@
M("`@("`@("`@("`@(",@<W1A<G0@;V8@>FEP"GT*;7D@0'!A<E]A<F=S.PIM
M>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T
M92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M87D@
M8F4@82!S96-U<FET>2!P<F]B;&5M*0HD<75I970@/2`P('5N;&5S<R`D14Y6
M>U!!4E]$14)51WT["FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@
M)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q
M=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T
M86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!
M4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8[
M"B1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@
M(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE
M("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH
M+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I
M;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*
M?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*
M?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@
M97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("="
M)RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD
M<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L
M("(^/B(L("0R(&]R(&1I92`B6%A8.B!#86YN;W0@;W!E;B!L;V<Z("0A(CL*
M?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*<VAI
M9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L
M971E("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@4$%2
M.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*
M)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]
M"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@>PI[
M"G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U
M:7)E($1I9V5S=#HZ4TA!.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY
M("1Z:7`["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D9F@L("<\)RP@
M)'!A<B!O<B!D:64@(D-A;FYO="!F:6YD("<D<&%R)SH@)"$B.PIB:6YM;V1E
M*"1F:"D["F)L97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E
M.CI::7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D
M<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@(E)E860@
M)R1P87(G(&5R<F]R.B`D(2(["GT*;7D@)65N=B`](&1O('L*:68@*"1Z:7`@
M86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*
M)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O7EQ3+BHO+VUS
M.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*;&]C86P@
M)"\@/2!<-#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(%!!4BP@)SPG+"`D
M<&%R(&]R(&1I92`B)"$Z("1P87(B.PIB:6YM;V1E*%!!4BD["F1I92`B)'!A
M<B!I<R!N;W0@82!005(@9FEL92(@=6YL97-S(#Q005(^(&5Q(")02UPP,#-<
M,#`T(CL*?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M
M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/
M7U=23TY,62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D
M:64@)"$["F)I;FUO9&4H)&9H*3L*)"\@/2`H9&5F:6YE9"`D9&%T85]P;W,I
M(#\@7"1D871A7W!O<R`Z('5N9&5F.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO
M861E<B`]('-C86QA<B`\7T9(/CL*:68@*"$D14Y6>U!!4E]615)"051)37T@
M86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2
M.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE
M=RT^87!P;'DH7"1L;V%D97(L("0P*0I]"F9O<F5A8V@@;7D@)&ME>2`H<V]R
M="!K97ES("5E;G8I('L*;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*
M)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["FUY("1M86=I
M8R`](")?7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*;7D@)'-E="`]
M(")005)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*)&QO861E<B`]?B!S>R1M
M86=I8R@@*RE]>PHD;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG=&@H)#$I
M("T@;&5N9W1H*"1S970I*2D*?65G.PI]"B1F:"T^<')I;G0H)&QO861E<BD[
M"B0O(#T@=6YD968["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V
M>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I
M.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!
M3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O
M;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#
M;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["FUY("5F:6QE<SL*)&9I;&5S
M>R1??2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A
M;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?
M97AT?3L*;7D@)7=R:71T96X["F9O<F5A8V@@*'-O<G0@:V5Y<R`E9FEL97,I
M('L*;7D@*"1N86UE+"`D9FEL92D["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@
M>PII9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1??2D@>PHD
M9FEL92`]("1?.PIL87-T.PI]"F5L<VEF("@O7BA<421D:7)<15PO*"XJ6UY#
M8UTI*5Q:+VDI('L**"1F:6QE+"`D;F%M92D@/2`H)#$L("0R*3L*;&%S=#L*
M?0IE;'-I9B`H;2%>+VQO861E<B];7B]=*R\H+BI;7D-C72E<6B$I('L*:68@
M*&UY("1R968@/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)#%]*2!["B@D
M9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0IE;'-I9B`H+68@
M(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I
M.PIL87-T.PI]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE(&%N9"!N
M;W0@)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD
M("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O.PIO=71S*"!J;VEN("(B+`IQ
M<2A086-K:6YG("(I+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I
M;&4L"G%Q*"(N+BXI"BD["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@
M>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;W!E;B!&24Q%
M+"`G/"<L("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B.PIB
M:6YM;V1E*$9)3$4I.PHD8V]N=&5N="`](#Q&24Q%/CL*8VQO<V4@1DE,13L*
M4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@
M)&9I;&4I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<
M+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^
M;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*;W5T<RAQ
M<2A7<FET=&5N(&%S("(D;F%M92(I*3L*)&9H+3YP<FEN="@B1DE,12(I.PHD
M9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DI.PHD9F@M
M/G!R:6YT*'-P<FEN=&8H"B(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP
M=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M90HI*3L*)&9H+3YP<FEN="AP86-K
M*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DI.PHD9F@M/G!R:6YT*"1C;VYT96YT
M*3L*?0I]"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*
M)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PII9B`H
M(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;.5TI
M('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["F]P96XH;7D@)&9H
M+"`B/"(L("1O=70I.PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H
M*3L*8VQO<V4H)&9H*3L*)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD:6=E<W0[
M"GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?
M;F%M92D["B1C86-H95]N86UE("X](")#04-(12(["B1F:"T^<')I;G0H)&-A
M8VAE7VYA;64I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@+2!L
M96YG=&@H)&QO861E<BDI*3L*)&9H+3YP<FEN="@D4$%27TU!1TE#*3L*)&9H
M+3YC;&]S93L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL
M97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U
M:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E
M<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@
M)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(",@07)C:&EV93HZ6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(86YD;&4*
M)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE("(D(3H@)$`B
M.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?1D@I.PIM>2`D>FEP
M(#T@07)C:&EV93HZ6FEP+3YN97<["B1Z:7`M/G)E861&<F]M1FEL94AA;F1L
M92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I(&]R
M(&1I92`B)"$Z("1`(CL*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H-C0@
M*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB
M0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["B1Q=6EE="`]("$D14Y6>U!!4E]$
M14)51WT["F]U=',H<7$H7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%
M35!](BDI.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L
M9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D;65M8F5R("@@
M)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R
M>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["FYE>'0@
M=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#;VYF
M:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C
M:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q
M.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!
M4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE("8F
M("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H
M<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E
M>&ES=',@870@(B1D97-T7VYA;64B*2D["GT@96QS92!["F]U=',H<7$H17AT
M<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(I*3L*)&UE
M;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I.PIC:&UO9"@P
M-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N
M;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID:64@/#P@(BXB
M('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I
M<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@70HD
M,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[4$%27U!2
M3T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U
M8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR97%U:7)E($9I;&4Z
M.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE
M.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["G)E<75I
M<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE
M<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0IS=6(@
M<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E<75I<F4@1'EN84QO
M861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER
M92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E($-A<G`["G)E<75I
M<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E<75I<F4@17AP;W)T
M97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR
M97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER
M92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L
M93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*
M<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["G)E
M<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$
M:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q=6ER92!0
M05(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T=')I8G5T97,[
M"F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER92!7:6XS,B!]
M.PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A;"![(')E<75I
M<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R97%U:7)E(%1I
M93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R97%U:7)E(%!E<FQ)
M3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L('L@<F5Q=6ER92!U
M=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6
M>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B1P
M87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM
M87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%
M35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2!["FYE>'0@=6YL
M97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*
M;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U:60I(#T@9V5T
M<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I;F5D*"97:6XS
M,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA
M;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R;F%M92`]("1P
M=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@
M)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0HD=7-E<FYA;64@/7X@<R]<5R]?
M+V<["FUY("1S=&UP9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L:6U]<&%R+2(N
M=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U
M.PII9B`H(21%3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@*'-T870H
M)'!R;V=N86UE*2E;.5TI('L*;W!E;B`H;7D@)&9H+"`B/"(N("1P<F]G;F%M
M92D["G-E96L@)&9H+"`M,3@L(#(["G-Y<W)E860@)&9H+"!M>2`D8G5F+"`V
M.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("TU."P@,CL*
M<WES<F5A9"`D9F@L("1B=68L(#0Q.PHD8G5F(#U^(',O7#`O+V<["B1S=&UP
M9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@)&)U9CL*?0IE;'-E
M('L*;7D@)&1I9V5S="`](&5V86P*>PIR97%U:7)E($1I9V5S=#HZ4TA!.PIM
M>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*;W!E;BAM>2`D9F@L("(\
M(BP@)'!R;V=N86UE*3L*8FEN;6]D92@D9F@I.PHD8W1X+3YA9&1F:6QE*"1F
M:"D["F-L;W-E*"1F:"D["B1C='@M/FAE>&1I9V5S=#L*?2`O+R`D;71I;64[
M"B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TD9&EG97-T(CL*
M?0IC;&]S92@D9F@I.PI]"F5L<V4@>PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PHD
M<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]=&5M<"TD)"(["GT*)$5.5GM0
M05)?5$5-4'T@/2`D<W1M<&1I<CL*;6MD:7(@)'-T;7!D:7(L(#`W-34["FQA
M<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%
M3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS=6(@7W1E;7!F:6QE('L*;7D@
M*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA;64@
M/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L;&YA;64I('L*
M;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["F]P96X@;7D@)&9H+"`G
M/B<L("1T96UP;F%M92!O<B!D:64@(F-A;B=T('=R:71E("1T96UP;F%M93H@
M)"$B.PIB:6YM;V1E("1F:#L*<')I;G0@)&9H("1C;VYT96YT<SL*8VQO<V4@
M)&9H.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN960@)&UO9&4[
M"G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T96UP
M;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G;F%M
M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM0
M05)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD
M<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X
M*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE
M(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)$-O;F9I
M9WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R
M(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2!["FEF
M("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US
M("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X97TB*2!["B1P
M<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H
M(&UY("1D:7(@*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]7$4O+"`D14Y6
M>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D
M9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D0V]N9FEG>U]D
M96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM
M?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D
M0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](CL**"@D<')O
M9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T
M*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS
M=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!
M4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E
M;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)$-O;F9I9WM?9&5L:6U])'!R
M;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_
M($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@
M5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N
M86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<12DO)'!W9"1#
M;VYF:6=[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M
M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!
M3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])
M3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!
M3B!$14)51R!#04-(12!04D]'3D%-12`I("D@>PID96QE=&4@)$5.5GLG4$%2
M7R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I
M('L*)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G+B1??2!I
M9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*?0IM>2`D<&%R7V-L
M96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@(CL*:68@
M*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!3GT["GT*
M96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.?2D@>PIM>2`D
M=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG=&@H(D-,14%.
M(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@/7X@+UY005)?
M0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T
M.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92![
M"G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N
M9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O
M;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE
M>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]
M"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"90
M05(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7$H
M<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.
M;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&XI"G5N;&5S<R`M92`D<')O9VYA
M;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?
M5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T52
M4D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)2
M3U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I
M9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@``7U]%3E9?4$%27T-,14%.7U\@
M("`@("`@("`@("`@("```'!E<FQX<VDN8P```````````````````````1L#
M.P```-0````9__^+.```!*S__X]@````\/__D!````$L__^08````4S__Y#X
M```!?/__DU@```&X__^4N````?#__Y58```"'/__E9@```(\__^5^````GC_
M_Y<0```"M/__EQ@```+(__^9"````P3__YDP```#&/__FF````,\__^;Z```
M`V#__YQ8```#C/__G(@```.L__^=.````_C__Z.0```$-/__IU````1P__^G
MP```!/#__[\8```%+/__OX@```50___`Z```!8P`````````%``````!>E(`
M`7@.`1L,#Z`!````````.````!S__XYH````L`!&A@Z'#8@,B0N*"HL)C`B-
M!XX&CP5&#L`"`H(*S\[-S,O*R<C'Q@Z@`4(+````'````%C__X[<````4`!4
MC@:/!48.T`)TS\X.H`$````L````>/__CPP```"8`$J*"HL)C`B-!XX&CP5&
M#M`"`H;/SLW,R\H.H`$````````X````J/__CW0```):`$J&#H<-B`R)"XH*
MBPF,"(T'C@:/!48.T`(#`DC/SLW,R\K)R,?&#J`!```````T````Y/__D9@`
M``%<`$J'#8@,B0N*"HL)C`B-!XX&CP5&#M@#`P%*S\[-S,O*R<C'#J`!````
M`"@```$<__^2P````)P`5(L)C`B-!XX&CP5&#M@#`H#/SLW,RPZ@`0``````
M'````4C__Y,T````/`!,C@:/!48.P`)DS\X.H`$````X```!:/__DU0```!:
M`$:&#H<-B`R)"XH*BPF,"(T'C@:/!48.R`("3,_.S<S+RLG(Q\8.H`$`````
M```X```!I/__DW@```$6`$J&#H<-B`R)"XH*BPF,"(T'C@:/!48.T$(#`03/
MSLW,R\K)R,?&#J`!```````0```!X/__E%0````&`````````#@```'T__^4
M2````>H`2H8.APV(#(D+B@J+"8P(C0>.!H\%1@[@(P,!V,_.S<S+RLG(Q\8.
MH`$``````!````(P__^5_````"(`````````(````D3__Y80```!+``"[HX&
MCP5&#L`"6,_.#J`!````````(````FC__Y<<```!B`!4C@:/!48.\`(#`6S/
MS@Z@`0``````*````HS__YB`````<`!:C@:/!48.P`)^"L_.#J`!0@M(#J`!
MSL\````````<```"N/__F,0````N`$:.!H\%1@[``F#/S@Z@`0```$@```+8
M__^8U````*P`1H8.APV(#(D+B@J+"8P(C0>.!H\%2@[``FP*S\[-S,O*R<C'
MQ@Z@`48+`FC/SLW,R\K)R,?&#J`!```````X```#)/__F3@```96`%2&#H<-
MB`R)"XH*BPF,"(T'C@:/!48.B(4"`P8ZS\[-S,O*R<C'Q@Z@`0`````X```#
M8/__GU0```/``$:&#H<-B`R)"XH*BPF,"(T'C@:/!48.P`(#`[+/SLW,R\K)
MR,?&#J`!```````X```#G/__HM@```!L`$:*"HL)C`B-!XX&CP5&#L`"`E(*
MS\[-S,O*#J`!1@M&S\[-S,O*#J`!``````!````#V/__AH0```(J`$:&#H<-
MB`R)"XH*BPF,"(T'C@:/!48.V`(#`?(*S\[-S,O*R<C'Q@Z@`4(+````````
M`````#@```0<__^BR```%U8`6(8.APV(#(D+B@J+"8P(C0>.!H\%1@[0!P,7
M-L_.S<S+RLG(Q\8.H`$``````"````18__^YY````&P`2HX&CP5&#L`"`EK/
MS@Z@`0```````#@```1\__^Z,````6``3(8.APV(#(D+B@J+"8P(C0>.!H\%
M5`[``@,!/L_.S<S+RLG(Q\8.H`$``````#0```2X__^[5````1H`1H@,B0N*
M"HL)C`B-!XX&CP5,#L`"`N`*S\[-S,O*R<@.H`%&"P``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````#__________P``````````____
M______\````````````````````!``````````$``````````0````````*R
M``````````\````````$-@`````````,````````&'``````````#0``````
M`%<X`````&___O4````````"&``````````%````````#"``````````!@``
M``````+P``````````H````````$5``````````+`````````!@`````````
M%0````````````````````,```````"MF``````````"````````!8@`````
M````%``````````'`````````!<````````2Z``````````'````````$'@`
M````````"`````````)P``````````D`````````&``````````8````````
M````````;___^P`````(```!`````&____D`````````#@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````J_@`````````````````
M````````````&,8````````8Y@```````!D&````````&28````````91@``
M`````!EF````````&88````````9I@```````!G&````````&>8````````:
M!@```````!HF````````&D8````````:9@```````!J&````````&J8`````
M```:Q@```````!KF````````&P8````````;)@```````!M&````````&V8`
M```````;A@```````!NF````````&\8````````;Y@```````!P&````````
M'"8````````<1@```````!QF````````'(8````````<I@```````!S&````
M````'.8````````=!@```````!TF````````'48````````=9@```````!V&
M````````':8````````=Q@```````!WF````````'@8````````>)@``````
M`!Y&````````'F8````````>A@```````!ZF````````'L8````````>Y@``
M`````!\&````````'R8````````?1@```````!]F````````'X8````````?
MI@```````!_&````````'^8````````@!@```````"`8````````````````
M`````````````%<X`````````````````````````````!AP````````````
M````````````````````````````````````````````````````````````
M`````````````````````+``````````68@```````!78```````````````
M````6$P```````!84````````%F.````````5[(```````!9E@``````````
M````````69H```````!9H```````````_____P````````````!:0D=#0SH@
M*$%L<&EN92`X+C,N,"D@."XS+C```"YS:'-T<G1A8@`N:6YT97)P`"YG;G4N
M:&%S:``N9'EN<WEM`"YD>6YS='(`+G)E;&$N9'EN`"YR96QA+G!L=``N:6YI
M=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M95]H9'(`+F5H7V9R86UE
M`"YC=&]R<P`N9'1O<G,`+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S`"YC;VUM
M96YT````````````````````````````````````````````````````````
M```````````````````````````````````````+`````0`````````"````
M`````@`````````"```````````8`````````````````````0``````````
M````$V____8``````````@````````(8`````````A@`````````V`````,`
M``````````````@``````````````!T````+``````````(````````"\```
M``````+P````````"3`````$`````@`````````(`````````!@````E````
M`P`````````"````````#"`````````,(`````````14````````````````
M`````0``````````````+0````0``````````@```````!!X````````$'@`
M```````"<`````,```````````````@`````````&````#<````$````````
M`$(````````2Z````````!+H````````!8@````#````$0`````````(````
M`````!@```!!`````0`````````&````````&'`````````8<``````````H
M`````````````````````@``````````````/`````$`````````!@``````
M`!B8````````&)@````````'@`````````````````````0`````````(```
M`$<````!``````````8````````@&````````"`8````````-R``````````
M```````````(``````````````!-`````0`````````&````````5S@`````
M``!7.``````````B`````````````````````@``````````````4P````$`
M`````````@```````%=@````````5V`````````]@```````````````````
M``@``````````````%L````!``````````(```````"4X````````)3@````
M`````-0````````````````````$``````````````!I`````0`````````"
M````````E;@```````"5N`````````3P````````````````````"```````
M````````<P````$``````````P```````*O8````````F]@`````````$```
M``````````````````@``````````````'H````!``````````,```````"K
MZ````````)OH`````````!`````````````````````(``````````````"!
M````!@`````````#````````J_@```````";^`````````&@````!```````
M````````"``````````0````B@````$``````````P```````*V8````````
MG9@````````":`````````````````````@`````````"````(\````!````
M``````,```````"P`````````*```````````'@````````````````````(
M``````````````"5````"``````````#````````L'@```````"@>```````
M`!!H````````````````````"```````````````F@````$`````````,```
M````````````````H'@`````````&@````````````````````$`````````
M`0````$````#`````````````````````````````*"2`````````*,`````
4```````````````!````````````
